coinor.blimpy.LinkedList'

Package coinor :: Package blimpy :: Module LinkedList' |
[hide private]
[frames] | no frames]

# Module LinkedList'

source code

Lists Module A basic linked list implementation conforming to the Python list API. It can be used as a drop-in replacement for the built-in list class. Created on Jan 29, 2012

Version: 1.1.0

Author: Ted Ralphs, Aykut Bulut (ted@lehigh.edu, ayb211@lehigh.edu)

License: BSD

Classes | [hide private]
| LinkedList implementation of link list data structure.
| Node Basic data type that LinkedList will contain pre: data that node will contain post: Node type object

Variables | [hide private]
| __email__ = ``'``ayb211@lehigh.edu``'``
| __maintainer__ = ``'``Aykut Bulut``'``
| __package__ = ``'``coinor.blimpy``'``
| __title__ = ``'``Linked list data structure``'``
| __url__ = `None`